summaryrefslogtreecommitdiff
path: root/lib/rss/0.9.rb
diff options
context:
space:
mode:
authorkou <kou@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2005-04-09 03:09:52 +0000
committerkou <kou@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2005-04-09 03:09:52 +0000
commit80861909e66342872332c47e57d8d42e68b0759c (patch)
tree47a070c926cf4cad42a7ec2d1cb6b2bc885b206d /lib/rss/0.9.rb
parent16cb9d65eda9e2a692b9f0f5299a477793a8ba11 (diff)
* lib/rss: backoported from HEAD.
* lib/rss: refactored. - gave a name to 'x'. - undef_method -> remove_method for avoiding a warning in ruby 1.6. * lib/rss/parser.rb: @@setter -> @@setters. * lib/rss/parser.rb (RSS::BaseListener.register_uri) (RSS::BaseListener.uri_registered?) (RSS::BaseListener.install_get_text_element): swapped the first argument and the second argument. * lib/rss/taxonomy.rb: swapped the first argument and the second argument for RSS::BaseListener.install_get_text_element. * lib/rss/image.rb: ditto. * lib/rss/syndication.rb: ditto. * lib/rss/dublincore.rb: ditto. * lib/rss/parser.rb: ditto. * lib/rss/1.0.rb: ditto. * lib/rss/2.0.rb: ditto. * lib/rss/0.9.rb: ditto. * lib/rss/content.rb: ditto. * lib/rss/parser.rb (RSS::BaseListener.install_setter) (RSS::BaseListener.register_uri): changed fallback way. * lib/rss/parser.rb: added class name registry for complex model elements. (ex. have childlen elements, have some attributes and a child element and so on.) * lib/rss/dublincore.rb: supported multiple Dublin Core items. * lib/rss/maker/dublincore.rb: ditto. * lib/rss/maker/image.rb: supproted new Dublin Core API. * lib/rss/maker/base.rb: added default current_element implementation. * lib/rss/trackback.rb (RSS::TrackBackUtils.new_with_value_if_need): moved to RSS::Utils. * lib/rss/utils.rb (RSS::Utils.new_with_value_if_need): moved from RSS::TrackBackUtils. * lib/rss/maker/image.rb: fixed invalid argument of add_need_initialize_variable bug. * lib/rss/maker/trackback.rb: ditto. * lib/rss/rss.rb (Hash#merge): added for ruby 1.6. * lib/rss/rss.rb (RSS::BaseModel.date_writer): changed to accept nil for date value. * test/test_dublincore.rb: added tests for plural accessor and multiple Dublin Core items. * test/test_setup_maker_1.0.rb: fixed swapped actual and expected values. * test/rss/rss-assertions.rb (assert_multiple_dublin_core): added an assertion for testing multiple Dublin Core items. * test/rss/test_maker_dc.rb (test_rss10_multiple): added a test for making multiple Dublin Core items. * test/rss/test_maker_dc.rb (test_date): added a test for #date= and #dc_date=. * sample/rss/tdiary_plugin/rss-recent.rb: new option: @options['rss-recent.use-image-link']: use image as link instread of text if available. * sample/rss/tdiary_plugin/rss-recent.rb (RSS_RECENT_VERSION): 0.0.5 -> 0.0.6. git-svn-id: svn+ssh://ci.ruby-lang.org/ruby/branches/ruby_1_8@8284 b2dd03c8-39d4-4d8f-98ff-823fe69b080e
Diffstat (limited to 'lib/rss/0.9.rb')
-rw-r--r--lib/rss/0.9.rb100
1 files changed, 51 insertions, 49 deletions
diff --git a/lib/rss/0.9.rb b/lib/rss/0.9.rb
index c780cdb66a..a473322612 100644
--- a/lib/rss/0.9.rb
+++ b/lib/rss/0.9.rb
@@ -25,8 +25,8 @@ module RSS
install_model(tag, occurs)
end
- %w(channel).each do |x|
- install_have_child_element(x)
+ %w(channel).each do |name|
+ install_have_child_element(name)
end
attr_accessor :rss_version, :version, :encoding, :standalone
@@ -78,7 +78,9 @@ module RSS
def _tags
[
[nil, 'channel'],
- ].delete_if {|x| send(x[1]).nil?}
+ ].delete_if do |uri, name|
+ send(name).nil?
+ end
end
def _attrs
@@ -101,17 +103,17 @@ module RSS
["webMaster", "?"],
["rating", "?"],
["docs", "?"],
- ].each do |x, occurs|
- install_text_element(x)
- install_model(x, occurs)
+ ].each do |name, occurs|
+ install_text_element(name)
+ install_model(name, occurs)
end
[
["pubDate", "?"],
["lastBuildDate", "?"],
- ].each do |x, occurs|
- install_date_element(x, 'rfc822')
- install_model(x, occurs)
+ ].each do |name, occurs|
+ install_date_element(name, 'rfc822')
+ install_model(name, occurs)
end
alias date pubDate
alias date= pubDate=
@@ -121,23 +123,23 @@ module RSS
["skipHours", "?"],
["image", nil],
["textInput", "?"],
- ].each do |x, occurs|
- install_have_child_element(x)
- install_model(x, occurs)
+ ].each do |name, occurs|
+ install_have_child_element(name)
+ install_model(name, occurs)
end
[
["cloud", "?"]
- ].each do |x, occurs|
- install_have_attribute_element(x)
- install_model(x, occurs)
+ ].each do |name, occurs|
+ install_have_attribute_element(name)
+ install_model(name, occurs)
end
[
["item", "*"]
- ].each do |x, occurs|
- install_have_children_element(x)
- install_model(x, occurs)
+ ].each do |name, occurs|
+ install_have_children_element(name)
+ install_model(name, occurs)
end
def initialize()
@@ -192,8 +194,8 @@ module RSS
"image",
"textInput",
"cloud",
- ].delete_if do |x|
- send(x).nil?
+ ].delete_if do |name|
+ send(name).nil?
end.collect do |elem|
[nil, elem]
end
@@ -234,9 +236,9 @@ module RSS
[
["day", "*"]
- ].each do |x, occurs|
- install_have_children_element(x)
- install_model(x, occurs)
+ ].each do |name, occurs|
+ install_have_children_element(name)
+ install_model(name, occurs)
end
def to_s(need_convert=true, indent=calc_indent)
@@ -279,9 +281,9 @@ module RSS
[
["hour", "*"]
- ].each do |x, occurs|
- install_have_children_element(x)
- install_model(x, occurs)
+ ].each do |name, occurs|
+ install_have_children_element(name)
+ install_model(name, occurs)
end
def to_s(need_convert=true, indent=calc_indent)
@@ -328,13 +330,13 @@ module RSS
include RSS09
- %w(url title link).each do |x|
- install_text_element(x)
- install_model(x, nil)
+ %w(url title link).each do |name|
+ install_text_element(name)
+ install_model(name, nil)
end
- %w(width height description).each do |x|
- install_text_element(x)
- install_model(x, "?")
+ %w(width height description).each do |name|
+ install_text_element(name)
+ install_model(name, "?")
end
def to_s(need_convert=true, indent=calc_indent)
@@ -355,8 +357,8 @@ module RSS
private
def _tags
- %w(url title link width height description).delete_if do |x|
- send(x).nil?
+ %w(url title link width height description).delete_if do |name|
+ send(name).nil?
end.collect do |elem|
[nil, elem]
end
@@ -409,12 +411,12 @@ module RSS
include RSS09
- %w(title link description).each do |x|
- install_text_element(x)
+ %w(title link description).each do |name|
+ install_text_element(name)
end
- %w(source enclosure).each do |x|
- install_have_child_element(x)
+ %w(source enclosure).each do |name|
+ install_have_child_element(name)
end
[
@@ -457,10 +459,10 @@ module RSS
def _tags
rv = %w(title link description author comments
- source enclosure).delete_if do |x|
- send(x).nil?
- end.collect do |x|
- [nil, x]
+ source enclosure).delete_if do |name|
+ send(name).nil?
+ end.collect do |name|
+ [nil, name]
end
@category.each do
@@ -607,9 +609,9 @@ module RSS
include RSS09
- %w(title description name link).each do |x|
- install_text_element(x)
- install_model(x, nil)
+ %w(title description name link).each do |name|
+ install_text_element(name)
+ install_model(name, nil)
end
def to_s(need_convert=true, indent=calc_indent)
@@ -628,8 +630,8 @@ module RSS
private
def _tags
- %w(title description name link).each do |x|
- send(x).nil?
+ %w(title description name link).each do |name|
+ send(name).nil?
end.collect do |elem|
[nil, elem]
end
@@ -644,8 +646,8 @@ module RSS
end
- RSS09::ELEMENTS.each do |x|
- BaseListener.install_get_text_element(x, nil, "#{x}=")
+ RSS09::ELEMENTS.each do |name|
+ BaseListener.install_get_text_element(nil, name, "#{name}=")
end
module ListenerMixin